# Generated by Django 2.1.4 on 2019-05-15 06:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0007_auto_20190514_1144'),
    ]

    operations = [
        migrations.AddField(
            model_name='urlseo',
            name='is_default',
            field=models.BooleanField(default=False, help_text='Default instance for all pages.', verbose_name='Is default'),
        ),
    ]
