<!--Base-->
{% if robots %}
    {% if debug %}
        <meta name="robots" content="noindex,nofollow">
    {% else %}
        <meta name="robots" content="{{ robots }}">
    {% endif %}
{% endif %}

{% if title %}
    <title>{{ title }}</title>
{% endif %}

{% if description %}
    <meta name="description" content="{{ description }}">
{% endif %}

{% if keywords %}
    <meta name="keywords" content="{{ keywords }}">
{% endif %}

<link rel="canonical" href="{{ canonical }}">

<!--OpenGraph-->
{% if facebook_app_id %}
    <meta property="fb:app_id" content="{{ facebook_app_id }}"/>
{% endif %}

<meta property="og:locale" content="{{ og_locale }}"/>

{% if og_type %}
    <meta property="og:type" content="{{ og_type }}">
{% endif %}

{% if title %}
    <meta property="og:title" content="{{ title }}">
{% endif %}

{% if description %}
    <meta property="og:description" content="{{ description }}">
{% endif %}

<meta property="og:site_name" content="{{ site_name }}"/>
<meta property="og:url" content="{{ canonical }}">

{% if image %}
    <meta property="og:image" content="{{ image }}">
    <meta property="og:image:secure_url" content="{{ image }}">
    <meta property="og:image:alt" content="{{ alt }}">
    <meta property="og:image:type" content="{{ mime_type }}">
    <meta property="og:image:width" content="{{ image_width }}">
    <meta property="og:image:height" content="{{ image_height }}">
{% endif %}

<!--Twitter card-->
{% if twitter_type %}
    <meta name="twitter:card" content="{{ twitter_type }}">
{% endif %}

{% if title %}
    <meta name="twitter:title" content="{{ title }}">
{% endif %}

{% if description %}
    <meta name="twitter:description" content="{{ description }}">
{% endif %}

{% if image %}
    <meta name="twitter:image" content="{{ image }}">
{% endif %}

<meta name="twitter:site" content="{{ site_name }}">
<meta name="twitter:domain" content="{{ site_name }}"/>
