# Generated by Django 2.1.4 on 2019-03-15 09:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0003_auto_20190121_0925'),
    ]

    operations = [
        migrations.AddField(
            model_name='modelinstanceseo',
            name='canonical',
            field=models.CharField(blank=True, max_length=255, verbose_name='Canonical'),
        ),
        migrations.AddField(
            model_name='viewseo',
            name='canonical',
            field=models.CharField(blank=True, max_length=255, verbose_name='Canonical'),
        ),
        migrations.AlterField(
            model_name='modelinstanceseo',
            name='alt',
            field=models.CharField(blank=True, max_length=255, verbose_name='Image alt text'),
        ),
        migrations.AlterField(
            model_name='modelinstanceseo',
            name='seo_text',
            field=models.TextField(blank=True, help_text='Can be useful for some static pages or some objects (like product category).', verbose_name='Seo text'),
        ),
        migrations.AlterField(
            model_name='viewseo',
            name='alt',
            field=models.CharField(blank=True, max_length=255, verbose_name='Image alt text'),
        ),
        migrations.AlterField(
            model_name='viewseo',
            name='seo_text',
            field=models.TextField(blank=True, help_text='Can be useful for some static pages or some objects (like product category).', verbose_name='Seo text'),
        ),
    ]
