__all__ = (
    'base_seo_fields',
)


base_seo_fields = (
    'object_type',
    'twitter_type',
    'index',
    'follow',
    'canonical',
    'title',
    'keywords',
    'description',
    'image',
    'width',
    'height',
    'alt',
    'h1',
    'seo_text'
)
