# Generated by Django 2.1.2 on 2019-03-23 20:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0004_auto_20190315_0939'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='modelinstanceseo',
            unique_together=set(),
        ),
    ]
